@@ -24,4 +24,6 @@ from .api import pie_chart_hashtags_terrorist
 from .api import NLP_analysis
 from .api import more_tweets_required
 from .api import profile_trend_visualization
-from .api import text_to_list_features_conversor
\ No newline at end of file
+from .api import text_to_list_features_conversor
+from .api import profile_max_tw_day_hourly_visualization
+from .api import final_pieChart
\ No newline at end of file
