@@ -251,7 +251,7 @@ def pie_chart_keywords_terrorist(data):
 	# Plot
 	ax1.pie(sizes, explode=explode, labels=labels, colors=colors, autopct='%1.1f%%', shadow=True, startangle=140)
 	ax2.pie(sizes2, explode=explode2, labels=labels2, colors=colors2, autopct='%1.1f%%', shadow=True, startangle=140)
-	plt.title('from '+str(len(data))+' tweets, '+ str(len(data_terr))+' tweets are belonging to Terroristic contents')
+	plt.title('From '+str(len(data))+' tweets, '+ str(len(data_terr))+' tweets are belonging to Terroristic contents')
 	plt.axis('equal')
 	plt.show()
 	
@@ -306,7 +306,7 @@ def pie_chart_hashtags_terrorist(data):
 	# Plot
 	ax1.pie(sizes, explode=explode, labels=labels, colors=colors, autopct='%1.1f%%', shadow=True, startangle=140)
 	ax2.pie(sizes2, explode=explode2, labels=labels2, colors=colors2, autopct='%1.1f%%', shadow=True, startangle=140)
-	plt.title('from '+str(len(data))+' tweets, '+ str(len(temp))+' tweets are following Terroristic Hashtags')
+	plt.title('From '+str(len(data))+' tweets, '+ str(len(temp))+' tweets are following Terroristic Hashtags')
 	plt.axis('equal')
 	plt.show() 
 
@@ -505,7 +505,7 @@ def graph_features(DiG,df):
     output = merge_dataframes(output, df_nodes_self_loop_iteration)
     return output
 
-def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret, iter_tw=1,save_by=300, filepath, filename):
+def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret, n_groups=1,save_by=300, filepath, filename):
     # get_user Returns the 20 most recent statuses posted from the authenticating user or the user specified. 
     profile_iter = save_by
     k=0
@@ -530,7 +530,7 @@ def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken
         itera=0
         max_id=""
         intentos = 0
-        while itera != iter_tw:
+        while itera != n_groups:
           try:
             if pri ==0:
               user=api.user_timeline(node_list1[i], count=200,tweet_mode="extended")      
@@ -556,7 +556,7 @@ def user_timeline_extraction (node_list, consumerKey, consumerSecret,accessToken
             if(intentos == 2):         
               list_users_noInfo.append(node_list1[i])
               intentos = 0
-              itera=iter_tw
+              itera=n_groups
         i = i+1       
       destino2 = time.time()
       aux=[]
